#!/usr/bin/php-cgi -q
<?php
// Lescript automatic updating script.
//
// This is an example of how Lescript can be used to automatically update
// expiring certificates.
//
// This code is based on FreePBX's LetsEncrypt integration
//
// Copyright (c) 2016 Rob Thomas <rthomas@sangoma.com>
// Licence:  AGPLv3.
//
// In addition, Stanislav Humplik <sh@analogic.cz> is explicitly granted permission
// to relicence this code under the open source licence of their choice.

if(!extension_loaded('openssl') || !extension_loaded('curl')) {
    die("You need at least PHP 5.2.6 with OpenSSL and curl extension\n");
}

if ($argc < 2) {
    die("USAGE: ".$argv[0]." domain\n");
}
$flag = file_exists('/opt/stasoft/bin/httpd.sh');
$default_webroot="/var/www/html";

if ($flag || (is_dir('/opt/stasoft/www/') && !is_dir($default_web_root)))
    $default_webroot="/opt/stasoft/www/";
// Configuration:
$doms = array();
for ($i = 1; $i < $argc; $i++)
    $doms[] = $argv[$i];

$domains = array(array('domains' => $doms, 'webroot' => $default_webroot));

$certlocation = "/etc/cert/lescript";

require 'Lescript.php';

// Always use UTC
date_default_timezone_set("UTC");

// Make sure our cert location exists
if (!is_dir($certlocation)) {
	// Make sure nothing is already there.
	if (file_exists($certlocation)) {
		unlink($certlocation);
	}
	mkdir ($certlocation);
}


foreach ($domains as $el) {
    if (!isset($el['webroot']) || !isset($el['domains'])) {
	continue;
    }
    // Do we need to create or upgrade our cert? Assume no to start with.
    $needsgen = false;
    $webroot = $el['webroot'];
    // Do we HAVE a certificate for all our domains?
    foreach ($el['domains'] as $d) {
	$certfile = "$certlocation/$d/cert.pem";

	if (!file_exists($certfile)) {
		// We don't have a cert, so we need to request one.
		$needsgen = true;
	} else {
		// We DO have a certificate.
		$certdata = openssl_x509_parse(file_get_contents($certfile));

		// If it expires in less than a month, we want to renew it.
		$renewafter = $certdata['validTo_time_t']-(86400*30);
		if (time() > $renewafter) {
			// Less than a month left, we need to renew.
			$needsgen = true;
		}
	}
    }
    // Do we need to generate a certificate?
    if ($needsgen) {
	$le = new Lescript($certlocation, $webroot);
	$le->initAccount();

	if ($flag) {
	    $ret = 0;
	    $res = array();
	    $retstr = exec('/opt/stasoft/bin/httpd.sh restart 80', $res, $ret);
	    if ($ret != 0) die("Could not restart local HTTP server ".$retstr."\n");
	}
	$le->signDomains($el['domains']);
	reset($el['domains']);
	foreach ($el['domains'] as $d) {
	    if (file_exists("$certlocation/$d/fullchain.pem") && file_exists("$certlocation/$d/private.pem")) {
		// Create a complete .pem file for use with haproxy or apache 2.4,
		// and save it as domain.name.pem for easy reference. It doesn't
		// matter that this is updated each time, as it'll be exactly
		// the same. 
		$pem = file_get_contents("$certlocation/$d/fullchain.pem")."\n".file_get_contents("$certlocation/$d/private.pem");
		file_put_contents("$certlocation/$d.pem", $pem);
		$pem_file = '/etc/cert/mini_httpd.pem';
		if (file_exists($pem_file)) {
		    unlink($pem_file);
		    file_put_contents($pem_file, $pem);
		}
	    }
	}
	if ($flag) {
	    $ret = 0;
	    $res = array();
	    $retstr = exec('/opt/stasoft/bin/httpd.sh restart', $res, $ret);
	    if ($ret != 0) die("Could not restart local HTTP server ".$retstr."\n");
	}
    }

}
