
CREATE TABLE sk_currency (
  currency_id serial4 PRIMARY KEY,
  sign varchar(12) NOT NULL default '',
  title varchar(128) NOT NULL default '',
  active CHAR(1) NOT NULL default 'Y' CHECK (active = 'Y' OR active = 'N'),
  "comment" TEXT
);

CREATE TABLE sk_currency_rate (
  rate_id serial8 PRIMARY KEY,
  currency_id int4 NOT NULL DEFAULT '0' CHECK (currency_id >= 0),
  rate_date date NOT NULL default '1970-01-01',
  rate numeric(16,2) NOT NULL default '1' CHECK (rate > 0)
);

CREATE TABLE sk_bank_info (
  id serial8 PRIMARY KEY,
  title TEXT NOT NULL,
  code TEXT NOT NULL,
  account TEXT NOT NULL,
  route_code TEXT NULL,
  obj_id int8 NOT NULL DEFAULT '1' CHECK (obj_id > 0)
);

CREATE TABLE sk_objects (
  obj_id serial8 PRIMARY KEY,
  fn varchar(128),
  mn varchar(128),
  ln varchar(128),
  "role" TEXT,
  nickname varchar(65),
  bday date NOT NULL default '1970-01-01',
  "comment" TEXT,
  street TEXT,
  extadd TEXT,
  locality TEXT,
  region TEXT,
  pcode TEXT,
  country TEXT,
  orgname TEXT,
  orgunit TEXT,
  url TEXT,
  email TEXT,
  home_phone TEXT,
  work_phone TEXT,
  cell_phone TEXT,
  exten TEXT,
  tax_num varchar(25) NULL,
  ss_num varchar(25) NULL,
  "password" varchar(65) NULL,
  add_date timestamp without time zone NOT NULL default '1970-01-01 00:00:00',
  last_date timestamp without time zone NOT NULL default '1970-01-01',
  "level" int4 NOT NULL default '0' CHECK (level >= 0 AND level < 100),
  active CHAR(1) NOT NULL default 'N' CHECK (active = 'Y' OR active = 'N'),
  resp_person int8 NOT NULL DEFAULT '0' CHECK (resp_person >= 0), 
  "mode" CHAR(1) NOT NULL default 'P'
 );

CREATE TABLE sk_providers (
	provider_id serial8 PRIMARY KEY,
	title varchar(128) NOT NULL,
	obj_id int8  NOT NULL DEFAULT '1' CHECK (obj_id > 0),
	exec_person int8 NOT NULL DEFAULT '0' CHECK (exec_person >= 0), 
	fin_person int8 NOT NULL DEFAULT '0' CHECK (fin_person >= 0), 
	adm_person int8 NOT NULL DEFAULT '0' CHECK (adm_person >= 0), 
	tech_person int8 NOT NULL DEFAULT '0' CHECK (tech_person >= 0) ,
	resp_person int8 NOT NULL DEFAULT '0' CHECK (resp_person >= 0), 
	"comment" TEXT,
	logo_url TEXT,
	add_date timestamp without time zone NOT NULL default '1970-01-01 00:00',
	last_date timestamp without time zone NOT NULL default '1970-01-01 00:00',
	"role" char(1) NOT NULL DEFAULT 'P' CHECK ("role" = 'P' OR "role" = 'R'),
	cashdesk char(1) default 'N' CHECK (cashdesk = 'Y' OR cashdesk = 'N'),
	c_sum numeric(16,2) not null default '0' CHECK (c_sum >= 0),
	c_percent numeric(7,4) not null default '0' CHECK (c_percent >= 0),
	key VARCHAR(64) NOT NULL DEFAULT '',
	active char(1) NOT NULL DEFAULT 'Y' CHECK (active = 'Y' OR active = 'N')
);

CREATE TABLE sk_operators (
    operator_id serial8 PRIMARY KEY,
    title varchar(128) NOT NULL,
    provider_id int8 NOT NULL DEFAULT '1' CHECK (provider_id > 0), 
    person_id int8 NOT NULL DEFAULT '0' CHECK (person_id > 0), 
    resp_person int8 NOT NULL DEFAULT '0' CHECK (resp_person >= 0), 
    add_date timestamp without time zone NOT NULL default '1970-01-01 00:00',
    last_date timestamp without time zone NOT NULL default '1970-01-01 00:00',
    "comment" TEXT,
    active CHAR(1) NOT NULL DEFAULT 'Y' CHECK (active = 'Y' OR active = 'N')
);

CREATE TABLE sk_service (
    service_id serial4 PRIMARY KEY,
    title VARCHAR(64),
    active CHAR(1) NOT NULL default 'Y' CHECK (active = 'Y' OR active = 'N'),
    "type" int2 NOT NULL default '0' CHECK ("type" >= 0),
    round_type int4 NOT NULL default '0' CHECK (round_type >= 0),	
    round_sign int4 NOT NULL default '2' CHECK (round_sign >= 0),
    "comment" TEXT
);

CREATE TABLE sk_service_set (
    service_set_id serial4 PRIMARY KEY,
    provider_id int8 not null default '1',
    service_id int4 not null default '1',
    currency_id int4  NOT NULL default '1' CHECK (currency_id > 0),
    price numeric(16,2) not null default '0' CHECK (price >= 0)
);

CREATE TABLE sk_accounts (
    "account_id" SERIAL8 PRIMARY KEY,
    "obj_id" INT8 NOT NULL DEFAULT '0' CHECK (obj_id >= 0),
    "service_set_id" int8 NOT NULL DEFAULT '1' CHECK (service_set_id > 0),
    "a_sum" numeric(16,2) NOT NULL DEFAULT '0',
    "credit_limit" numeric(16,2) NOT NULL DEFAULT '0' CHECK (credit_limit >= 0),
    "actual_doc_id" int8 NOT NULL DEFAULT '0' CHECK (actual_doc_id >= 0),
    "last_change" TIMESTAMP WITHOUT TIME ZONE NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "resp_person" int8 NOT NULL DEFAULT '0' CHECK (resp_person >= 0),
    "int_property" int8 NOT NULL DEFAULT '0' CHECK (int_property >= 0),
    "comment" TEXT
    );

CREATE TABLE sk_acl (
    acl_id serial4 PRIMARY KEY,
    uid int8  default NULL CHECK (uid >= 0),
    gid int8  default NULL CHECK (gid >= 0),
    "type" int2  NOT NULL default '0' CHECK (type >= 0),
    allow int2  NOT NULL default '0' CHECK (allow = 0 OR allow = 1),
    "rule" TEXT NOT NULL default '',
    time_rule TEXT NULL,
    active CHAR(1) NOT NULL default 'Y' CHECK (active = 'Y' OR active = 'N'),
    "comment" TEXT
);

CREATE TABLE sk_holidays (
    holiday_date date NOT NULL default '2008-01-01' PRIMARY KEY,
    service_set_id int8 not null default '1' check (service_set_id > 0),
    comment varchar(64)
) WITHOUT OIDS;

CREATE TABLE sk_reseller_tracker (
	provider_id int8  default '1' NOT NULL CHECK (provider_id > 0),
	reseller_id int8  default '0' NOT NULL CHECK (reseller_id > 0)
) WITHOUT OIDS;
