DROP TRIGGER IF EXISTS sk_provider_del ON sk_providers CASCADE;
DROP TRIGGER IF EXISTS sk_provider_add ON sk_providers CASCADE;
DROP TRIGGER IF EXISTS sk_currency_del ON sk_currency CASCADE;
DROP TRIGGER IF EXISTS sk_object_del ON sk_objects CASCADE;
DROP TRIGGER IF EXISTS sk_service_del ON sk_service CASCADE;
DROP TRIGGER IF EXISTS sk_service_set_del ON sk_service_set CASCADE;

CREATE OR REPLACE FUNCTION sk_cur_del()
RETURNS trigger AS '
BEGIN
DELETE FROM sk_currency_rate WHERE currency_id=OLD.currency_id;
UPDATE sk_service_set SET currency_id=1 WHERE sk_service_set.currency_id=OLD.currency_id;
RETURN OLD;
END;
' LANGUAGE 'plpgsql' VOLATILE;

CREATE OR REPLACE FUNCTION sk_obj_del()
RETURNS trigger AS '
DECLARE
    old_id int8;
    old_role char(1);
BEGIN
old_id := OLD.obj_id;
old_role := OLD."mode";
IF (old_role = ''P'') THEN
	UPDATE sk_objects SET resp_person=0 WHERE sk_objects.resp_person=old_id;
	DELETE FROM sk_operators WHERE person_id=old_id;
	UPDATE sk_operators SET resp_person=0 WHERE sk_operators.resp_person=old_id;
	UPDATE sk_providers SET resp_person=0 WHERE sk_providers.resp_person=old_id;
	UPDATE sk_providers SET exec_person=0 WHERE sk_providers.exec_person=old_id;
	UPDATE sk_providers SET fin_person=0 WHERE sk_providers.fin_person=old_id;
	UPDATE sk_providers SET adm_person=0 WHERE sk_providers.adm_person=old_id;
	UPDATE sk_providers SET tech_person=0 WHERE sk_providers.tech_person=old_id;
ELSIF (old_role = ''C'') THEN
	DELETE FROM sk_providers WHERE sk_providers.obj_id=old_id;
END IF;
	DELETE FROM sk_accounts WHERE sk_accounts.obj_id=old_id;
	DELETE FROM sk_bank_info WHERE sk_bank_info.obj_id=old_id;
RETURN OLD;
END;
' LANGUAGE plpgsql VOLATILE;


CREATE OR REPLACE FUNCTION sk_srv_del()
RETURNS trigger AS '
BEGIN
	DELETE FROM sk_service_set WHERE sk_service_set.service_id=OLD.service_id;
	RETURN OLD;
END;
' LANGUAGE plpgsql VOLATILE;

CREATE OR REPLACE FUNCTION sk_prov_del()
RETURNS trigger AS '
BEGIN
DELETE FROM sk_operators WHERE sk_operators.provider_id=OLD.provider_id;
IF (OLD."role" = ''P'') THEN
DELETE FROM sk_service_set WHERE sk_service_set.provider_id=OLD.provider_id;
DELETE FROM sk_reseller_tracker WHERE sk_reseller_tracker.provider_id=OLD.provider_id;
ELSIF (OLD."role" = ''R'') THEN
DELETE FROM sk_reseller_tracker WHERE sk_reseller_tracker.reseller_id=OLD.provider_id;
END IF;
RETURN OLD;
END;
' LANGUAGE plpgsql VOLATILE;

CREATE OR REPLACE FUNCTION sk_prov_add()
RETURNS trigger AS '
DECLARE
    ssid int8;
BEGIN
IF (NEW."role" = ''P'') THEN
    INSERT INTO sk_service_set (provider_id, service_id, currency_id) VALUES (NEW.provider_id, 1, 1);
    SELECT service_set_id INTO ssid FROM sk_service_set WHERE provider_id=NEW.provider_id AND service_id=1 AND currency_id=1;
    IF (ssid IS NOT NULL) THEN
	INSERT INTO sk_accounts (obj_id, service_set_id, resp_person) VALUES(NEW.obj_id, ssid, NEW.fin_person);
    END IF;
END IF;
RETURN NEW;
END;
' LANGUAGE plpgsql VOLATILE;

CREATE OR REPLACE FUNCTION sk_srv_set_del()
RETURNS trigger AS '
BEGIN
DELETE FROM sk_accounts WHERE sk_accounts.service_set_id=OLD.service_set_id;
DELETE FROM sk_holidays WHERE sk_holidays.service_set_id=OLD.service_set_id;
RETURN OLD;
END;
' LANGUAGE plpgsql VOLATILE;


CREATE TRIGGER sk_currency_del BEFORE DELETE ON sk_currency FOR EACH ROW EXECUTE PROCEDURE sk_cur_del();
CREATE TRIGGER sk_service_del BEFORE DELETE ON sk_service FOR EACH ROW EXECUTE PROCEDURE sk_srv_del();
CREATE TRIGGER sk_service_set_del BEFORE DELETE ON sk_service_set FOR EACH ROW EXECUTE PROCEDURE sk_srv_set_del();
CREATE TRIGGER sk_prov_del_tg BEFORE DELETE ON sk_providers FOR EACH ROW EXECUTE PROCEDURE sk_prov_del();
CREATE TRIGGER sk_prov_add_tg AFTER INSERT ON sk_providers FOR EACH ROW EXECUTE PROCEDURE sk_prov_add();
CREATE TRIGGER sk_object_del BEFORE DELETE ON sk_objects FOR EACH ROW EXECUTE PROCEDURE sk_obj_del();
