
CREATE TABLE sk_currency (
  currency_id integer PRIMARY KEY,
  sign TEXT NOT NULL default '',
  title TEXT NOT NULL default '',
  active TEXT NOT NULL default 'Y' CHECK (active = 'Y' OR active = 'N'),
  "comment" TEXT
);

CREATE TABLE sk_currency_rate (
  rate_id integer PRIMARY KEY,
  currency_id integer NOT NULL DEFAULT '2' CHECK (currency_id > 1),
  rate_date text NOT NULL default (date('now')),
  rate numeric(16,2) NOT NULL default '1' CHECK (rate > 0)
);

CREATE TABLE sk_bank_info (
  id integer PRIMARY KEY,
  title TEXT NOT NULL,
  code TEXT NOT NULL,
  account TEXT NOT NULL,
  route_code TEXT NULL,
  obj_id integer NOT NULL DEFAULT '0' CHECK (obj_id >= 0)
);

CREATE TABLE sk_objects (
  obj_id integer PRIMARY KEY,
  fn TEXT,
  mn TEXT,
  ln TEXT,
  "role" TEXT,
  nickname TEXT,
  bday text NOT NULL default '1970-01-01',
  "comment" TEXT,
  street TEXT,
  extadd TEXT,
  locality TEXT,
  region TEXT,
  pcode TEXT,
  country TEXT,
  orgname TEXT,
  orgunit TEXT,
  url TEXT,
  email TEXT,
  home_phone TEXT,
  work_phone TEXT,
  cell_phone TEXT,
  exten TEXT,
  tax_num TEXT,
  ss_num TEXT,
  "password" TEXT,
  add_date text NOT NULL default (datetime('now')),
  last_date text NOT NULL default (datetime('now')),
  "level" integer NOT NULL default '0' CHECK (level >= 0 AND level < 100),
  active TEXT NOT NULL default 'N' CHECK (active = 'Y' OR active = 'N'),
  resp_person integer NOT NULL DEFAULT '0' CHECK (resp_person >= 0), 
  "mode" TEXT NOT NULL default 'P'
 );

CREATE TABLE sk_providers (
	provider_id integer PRIMARY KEY,
	title TEXT NOT NULL,
	obj_id integer  NOT NULL DEFAULT '1' CHECK (obj_id > 0),
	exec_person integer NOT NULL DEFAULT '0' CHECK (exec_person >= 0), 
	fin_person integer NOT NULL DEFAULT '0' CHECK (fin_person >= 0), 
	adm_person integer NOT NULL DEFAULT '0' CHECK (adm_person >= 0), 
	tech_person integer NOT NULL DEFAULT '0' CHECK (tech_person >= 0) ,
	resp_person integer NOT NULL DEFAULT '0' CHECK (resp_person >= 0), 
	"comment" TEXT,
	logo_url TEXT,
	add_date text NOT NULL default (datetime('now')),
	last_date text NOT NULL default (datetime('now')),
	"role" TEXT NOT NULL DEFAULT 'P' CHECK ("role" = 'P' OR "role" = 'R'),
	cashdesk TEXT default 'N' CHECK (cashdesk = 'Y' OR cashdesk = 'N'),
	c_sum numeric(16,2) not null default '0' CHECK (c_sum >= 0),
	c_percent numeric(7,4) not null default '0' CHECK (c_percent >= 0),
	key text NOT NULL DEFAULT '',
	active TEXT NOT NULL DEFAULT 'Y' CHECK (active = 'Y' OR active = 'N')
	);

CREATE TABLE sk_operators (
  operator_id integer PRIMARY KEY,
  title TEXT NOT NULL,
  provider_id integer NOT NULL DEFAULT '1' CHECK (provider_id > 0), 
  person_id integer NOT NULL DEFAULT '0' CHECK (person_id > 0), 
  resp_person integer NOT NULL DEFAULT '0' CHECK (resp_person >= 0), 
  add_date text NOT NULL default (datetime('now')),
  last_date text NOT NULL default (datetime('now')),
  "comment" TEXT,
  active TEXT NOT NULL DEFAULT 'Y' CHECK (active = 'Y' OR active = 'N')
 );

CREATE TABLE sk_service (
    service_id integer PRIMARY KEY,
    title text not null,
    active text not null default 'Y' CHECK (active = 'Y' OR active = 'N'),
    "type" integer not null default '0' CHECK ("type" >= 0),
    round_type integer not null default '0' CHECK (round_type >= 0),	
    round_sign integer not null default '2' CHECK (round_sign >= 0),
    "comment" TEXT
);

CREATE TABLE sk_service_set (
    service_set_id integer PRIMARY KEY,
    provider_id integer not null default '1' CHECK (provider_id > 0),
    service_id integer not null default '1' CHECK (service_id > 0),
    currency_id integer not null default '1' CHECK (currency_id > 0),
    price numeric(16,2) not null default '0.0' CHECK (price >= 0)
);

CREATE TABLE sk_accounts (
    "account_id" integer PRIMARY KEY,
    "obj_id" integer not null default '0' CHECK (obj_id >= 0),
    "service_set_id" integer not null default '1' CHECK (service_set_id > 0),
    "a_sum" numeric(16,2) not null default '0',
    "credit_limit" numeric(16,2) not null default '0' CHECK (credit_limit >= 0),
    "actual_doc_id" integer not null default '0' CHECK (actual_doc_id >= 0),
    "last_change" text not null default (datetime('now')),
    "resp_person" integer not null default '0' CHECK (resp_person >= 0),
    "int_property" integer not null default '0' CHECK (int_property >= 0),
    "comment" TEXT
);

CREATE TABLE sk_acl (
  acl_id integer PRIMARY KEY,
  provider_id integer NOT NULL default '0' CHECK (provider_id > 0),
  service_id integer NOT NULL DEFAULT '0' CHECK (service_id >= 0),
  uid integer default '0' NOT NULL CHECK (uid >= 0),
  gid integer default '0' NOT NULL CHECK (gid >= 0),
  "type" integer NOT NULL default '0' CHECK (type >= 0),
  allow integer NOT NULL default '0' CHECK (allow = 0 OR allow = 1),
  "rule" TEXT NOT NULL default '',
  time_rule TEXT NULL,
  active TEXT NOT NULL default 'Y' CHECK (active = 'Y' OR active = 'N'),
  "comment" TEXT
);

CREATE TABLE sk_holidays (
  holiday_date text NOT NULL default '2008-01-01' PRIMARY KEY,
  provider_id integer not null default '1',
  service_id integer not null default '1',
  comment TEXT
);

CREATE TABLE sk_reseller_tracker (
	provider_id integer  default '1' NOT NULL CHECK (provider_id > 0),
	reseller_id integer  default '1' NOT NULL CHECK (reseller_id > 0)
);
