#!/bin/sh

get_num_of_cores() {
    grep processor /proc/cpuinfo | wc -l
}

get_ram_size() {
    expr $(expr $(free | tail -n +2 | head -n 1 | awk '{ print $2; }') / 1024) / 1024
}

grep -v listen_address $FNAME | grep -v max_connections $FNAME | grep -v shared_buffers $FNAME | 
grep -v effective_cache_size $FNAME | grep -v maintenance_work_mem $FNAM | grep -v work_mem $FNAME |
grep -v wal_buffers $FNAME | grep -v min_val_size $FNAME | grep -v max_wal_size $FNAME


function my_pgtune($connections = 100, $numcores=1, $ramsize=2, $storage='HDD', $streaming=false, $master=true) {
    $rec = '';
    $hba = '';
    $sql = '';
    if ($connections < 10)
	$connections = 10;
    $ctx = "listen_address=0.0.0.0
max_connections = ".$connections."\n";

    $allmem = $ramsize * 1024;
    $shared = intval($allmem / 4);
    $cache = $allmem - $shared;
    $ctx .= "shared_buffers = ".$shared."MB
effective_cache_size = ".$cache."MB\n";
    $ctx .= "maintenance_work_mem = ".intval(64*$ramsize)."MB
work_mem = ".intval(1024*$shared/$connections)."KB\n";
    if ($ramsize >= 2)
	$ctx .= "wal_buffers = 16MB\n";
    else
	$ctx .= "wal_buffers = 7864KB\n";
    $ctx .= "checkpoint_completion_target = 0.7
default_statistics_target = 100
min_val_size = 1GB
max_val_size = 2GB\n";
    if ($storage === 'HDD')
	$ctx .= "random_page_cost = 4
effective_io_concurrency = 2\n";
    if ($numcores > 1) {
	$ctx .= "max_worker_processes = ".$numcores."
max_parralel_workers_per_gather = ".intval($numcores/2)."\n";
    }
    if ($streaming) {
	$ctx .= "wal_level = hot_standby
max_wal_senders = 5
wal_keep_segments = 32
archive_mode = on
archive_command = 'cp %p /mnt/data/postgres/archive/%f'\n";
	if (!$master) {
	    $ctx .= "hot_stanby = 0n\n";
	}
    }
    return $ctx;
}

if ($argc < 5)
    exit(1);

echo(my_pgtune($argv[1], $argv[2], $argv[3], $argv[4]));

?>
